@@ -1,5 +1,6 @@
 from .bedwars import Bedwars
 from .skywars import Skywars
+from .blitz import Blitz
 from .duels import Duels
 import datetime
 from .. import utils
@@ -69,6 +70,7 @@ class HypixelPlayer:
         self.social = Social(data)
         self.bedwars = Bedwars(data)
         self.skywars = Skywars(data)
+        self.blitz = Blitz(data)
         self.duels = Duels(data)
 
     def __str__(self):
