@@ -237,6 +237,6 @@ def get_rank_color(rank):
 def get_profile_display(name, rank):
     # returns either "[rank] name" or "name" depending on whether the player has a rank
     if bool(rank):
-        return f"[{rank} {name}]"
+        return f"[{rank}] {name}"
     else:
         return name
